==> eclipse-platform-team_4.9.orig.tar.xz: eclipse-platform-team-4.9/examples/org.eclipse.team.examples.filesystem/src/org/eclipse/team/examples/pessimistic/ui/ConfigurationWizard.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2005 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.examples.pessimistic.ui;
 
import org.eclipse.core.resources.IProject;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.team.core.RepositoryProvider;
import org.eclipse.team.core.TeamException;
import org.eclipse.team.examples.pessimistic.PessimisticFilesystemProviderPlugin;
import org.eclipse.team.ui.IConfigurationWizard;
import org.eclipse.ui.IWorkbench;

/**
 * A wizard which adds the <code>PessimisticFilesystemProvider</code> nature
 * to a given project.
 */
public class ConfigurationWizard extends Wizard implements IConfigurationWizard {
	/*
	 * The project in question.
	 */
	private IProject project;
	
	/*
	 * @see Wizard#addPages()
	 */
	public void addPages() {
		// workaround the wizard problem
		addPage(new BlankPage());
	}

	/*
	 * @see Wizard#performFinish()
	 */
	public boolean performFinish() {
		try {
			RepositoryProvider.map(project, PessimisticFilesystemProviderPlugin.NATURE_ID);
		} catch (TeamException e) {
			PessimisticFilesystemProviderPlugin.getInstance().logError(e, "Could not set sharing on " + project);
			return false;
		}
		return true;
	}

	/*
	 * @see IConfigurationWizard#init(IWorkbench, IProject)
	 */	
	public void init(IWorkbench workbench, IProject project) {
		this.project = project;
	}
}

==> eclipse-platform-team_4.14.orig.tar.xz: eclipse-platform-team-4.14/examples/org.eclipse.team.examples.filesystem/src/org/eclipse/team/examples/pessimistic/ui/ConfigurationWizard.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2005 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.examples.pessimistic.ui;
 
import org.eclipse.core.resources.IProject;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.team.core.RepositoryProvider;
import org.eclipse.team.core.TeamException;
import org.eclipse.team.examples.pessimistic.PessimisticFilesystemProviderPlugin;
import org.eclipse.team.ui.IConfigurationWizard;
import org.eclipse.ui.IWorkbench;

/**
 * A wizard which adds the <code>PessimisticFilesystemProvider</code> nature
 * to a given project.
 */
public class ConfigurationWizard extends Wizard implements IConfigurationWizard {
	/*
	 * The project in question.
	 */
	private IProject project;
	
	@Override
	public void addPages() {
		// workaround the wizard problem
		addPage(new BlankPage());
	}

	@Override
	public boolean performFinish() {
		try {
			RepositoryProvider.map(project, PessimisticFilesystemProviderPlugin.NATURE_ID);
		} catch (TeamException e) {
			PessimisticFilesystemProviderPlugin.getInstance().logError(e, "Could not set sharing on " + project);
			return false;
		}
		return true;
	}

	@Override
	public void init(IWorkbench workbench, IProject project) {
		this.project = project;
	}
}
